script.on_event(defines.events.on_player_created, function(event)
  local player = game.players[event.player_index]
  player.insert{name="iron-plate", count=8}
  player.insert{name="pistol", count=1}
  player.insert{name="firearm-magazine", count=10}
  player.insert{name="burner-mining-drill", count = 1}
  player.insert{name="stone-furnace", count = 1}
  player.force.chart(player.surface, {{player.position.x - 200, player.position.y - 200}, {player.position.x + 200, player.position.y + 200}})
  if (#game.players <= 1) then
    game.show_message_dialog{text = {"msg-intro"}}
  else
    player.print({"msg-intro"})
  end
end)

script.on_event(defines.events.on_player_respawned, function(event)
  local player = game.players[event.player_index]
  player.insert{name="pistol", count=1}
  player.insert{name="firearm-magazine", count=10}
end)

script.on_event(defines.events.on_rocket_launched, function(event)
  local force = event.rocket.force
  if event.rocket.get_item_count("satellite") == 0 then
    if (#game.players <= 1) then
      game.show_message_dialog{text = {"gui-rocket-silo.rocket-launched-without-satellite"}}
    else
      for index, player in pairs(force.players) do
        player.print({"gui-rocket-silo.rocket-launched-without-satellite"})
      end
    end
    return
  end
  if not global.satellite_sent then
    global.satellite_sent = {}
  end
  if global.satellite_sent[force.name] then
    global.satellite_sent[force.name] = global.satellite_sent[force.name] + 1   
  else
    game.set_game_state{game_finished=true, player_won=true, can_continue=true}
    global.satellite_sent[force.name] = 1
  end
  for index, player in pairs(force.players) do
    if player.gui.left.rocket_score then
      player.gui.left.rocket_score.rocket_count.caption = tostring(global.satellite_sent[force.name])
    else
      local frame = player.gui.left.add{name = "rocket_score", type = "frame", direction = "horizontal", caption={"score"}}
      frame.add{name="rocket_count_label", type = "label", caption={"", {"rockets-sent"}, ":"}}
      frame.add{name="rocket_count", type = "label", caption=tostring(global.satellite_sent[force.name])}
    end
  end 
end)

script.on_event(defines.events.on_player_joined_game, function(event)
  local player = game.players[event.player_index]
  player.print({"", "Welcome"})
  if player.gui.left.PlayerList ~= nil then
    player.gui.left.PlayerList.destroy()
  end
  if player.gui.center.README ~= nil then
    player.gui.center.README.destroy()
  end
  if player.gui.top.PlayerList ~= nil then
    player.gui.top.PlayerList.destroy()
  end
  drawToolbar()
  drawPlayerList(player)
end)

script.on_event(defines.events.on_player_left_game, function(event)
  local player = game.players[event.player_index]
  drawPlayerList(player)
end)

script.on_event(defines.events.on_gui_click, function(event)
  local player = game.players[event.player_index]
  if event.element.name == "btn_readme" then
    README_Controller(player, "Rules", true)
  elseif event.element.name == "btn_readme_rules" then
    player.gui.center.README.destroy()
    README_Controller(player, "Rules")
  elseif event.element.name == "btn_readme_server_info" then
    player.gui.center.README.destroy()
    README_Controller(player, "Server info")
  elseif event.element.name == "btn_readme_chat" then
    player.gui.center.README.destroy()
    README_Controller(player, "Chat")
  elseif event.element.name == "btn_readme_admins" then
    player.gui.center.README.destroy()
    README_Controller(player, "Admins")
  elseif event.element.name == "btn_readme_players" then
    player.gui.center.README.destroy()
    README_Controller(player, "Players")
  elseif event.element.name == "btn_readme_close" then
    player.gui.center.README.destroy()
  elseif event.element.name == "btn_toolbar_playerList" then
    playerListGuiSwitch(player)
  elseif event.element.name == "btn_toolbar_getPlayerInventory" then
    drawGetPlayerInventory(player, nil)
  elseif event.element.name == "btn_getPlayerInventory_close" then
    player.gui.center.getPlayerInventory.destroy()
  elseif event.element.name == "btn_toolbar_rocket_score" then
    satelliteGuiSwitch(player)
  end
end)

function ticktohour (tick)
  	local hour = tostring(math.floor((tick * 0.01667) / 3600))
    return hour
end

function random ()
    local random = tostring(math.random(999))
    return random
end

function drawToolbar()
  for i, a in pairs(game.players) do
    if a.gui.top.Toolbar ~= nil then
      a.gui.top.Toolbar.destroy()
    end
    local frame = a.gui.top.add{name= "Toolbar", type = "frame", direction = "vertical"}
          frame.add{type = "flow", name= "flow1",direction = "horizontal", vertical_scroll_policy= "auto"}
          frame.flow1.add{name="btn_readme", type = "button", caption="Readme", tooltip= "Rules, Server info, How to chat, Playerlist, Adminlist."}
          frame.flow1.add{name="btn_toolbar_playerList", type = "button", caption="Playerlist", tooltip= "Adds a player list to your game."}
          frame.flow1.add{name="btn_toolbar_rocket_score", type = "button", caption="Rocket score", tooltip= "Show the satellite launched counter."}
  end
end

function satelliteGuiSwitch(play)
  if play.gui.left.rocket_score ~= nil then
    if play.gui.left.rocket_score.style.visible == true then
      play.gui.left.rocket_score.style.visible = false
    else
      play.gui.left.rocket_score.style.visible = true
    end
  end
end

function playerListGuiSwitch(play)
  if play.gui.left.PlayerList ~= nil then
    if play.gui.left.PlayerList.style.visible == true then
      play.gui.left.PlayerList.style.visible = false
    else
      play.gui.left.PlayerList.style.visible = true
    end
  end
end

function drawPlayerTable(play, guiroot, tablename, isAdminonly, buttonName, buttonCaption)
  local collumns = 4
  if buttonName ~= nil then
    collumns = 5
  end
  guiroot.add{name=tablename, type="table", colspan=collumns}
  guiroot[tablename].style.minimal_width = 500
  guiroot[tablename].style.maximal_width = 500
  guiroot[tablename].add{name="id", type="label", caption="id"}
  guiroot[tablename].add{name="name", type="label", caption="name"}
  guiroot[tablename].add{name="status", type="label", caption="status"}
  guiroot[tablename].add{name="hours", type="label", caption="Hours"}
  if buttonName ~= nil then 
    guiroot[tablename].add{name=buttonName, type="label", caption=buttonCaption}
  end
  for i, player in pairs(game.players) do
    if isAdminonly == true and player.admin == false then
      break
    else
      guiroot[tablename].add{name=random(), type="label", caption=i}
      guiroot[tablename].add{name=random() .. player.name, type="label", caption=player.name}
      if playerconnected == true then
        guiroot[tablename].add{name=random() .. player.name .. "Status", type="label", caption="ONLINE"}
      else
        guiroot[tablename].add{name=random() .. player.name .. "Status", type="label", caption="OFFLINE"}
      end
      guiroot[tablename].add{name=random() .. player.name .. "Hours", type="label", caption=ticktohour(player.online_time)}
      if buttonName ~= nil then 
        guiroot[tablename].add{name=random() .. buttonName .. player.name, type = "button", caption=buttonCaption}
      end
    end
  end
end

function drawPlayerList (play)
  for i, a in pairs(game.players) do
    if a.gui.left.PlayerList ~= nil then
      a.gui.left.PlayerList.destroy()
    end
    local frame = a.gui.left.add{name= "PlayerList", type = "frame", direction = "vertical"}
        frame.add{type = "flow", name= "flow",direction = "vertical", vertical_scroll_policy= "auto"}
    for i, player in pairs(game.players) do
      if player.connected == true then
        local random = random()
        if player.admin == true then
          if player.name == "badgamernl" or player.name == "BADgamerNL" then
            frame.flow.add{type = "label",  name=random .. player.name, style="caption_label_style", caption={"", ticktohour(player.online_time), " H - " , player.name , " - OWNER"}}
            frame.flow[random .. player.name].style.font_color = {r=170,g=0,b=0}
          else
            frame.flow.add{type = "label",  name=random .. player.name, style="caption_label_style", caption={"", ticktohour(player.online_time), " H - " , player.name , " - ADMIN"}}
            frame.flow[random .. player.name].style.font_color = {r=233,g=63,b=233}
          end
        else
          frame.flow.add{type = "label",  name=random .. player.name, style="caption_label_style", caption={"", ticktohour(player.online_time), " H - " , player.name}}
          frame.flow[random .. player.name].style.font_color = {r=255,g=159,b=27}
        end
      end
    end
  end
end

function README_Controller(play, page, btn)
  local rules = {
    "Hacking/cheating, exploiting and abusing bugs is not allowed.",
    "Do not disrespect any player in the server (This includes staff).",
    "Do not spam, this includes stuff such as chat spam, item spam, chest spam etc.",
    "Do not laydown concrete with bots when you dont have permission to.",
    "Do not make train roundabouts.",
    "Do not ask for rank.",
    "Use common sense",
  }
  local chat = {
    "Chatting for new players can be difficult because it’s different than other games!",
    "It’s very simple, the button you need to press is the “GRAVE/TILDE key”",
    "it’s located under the “ESC key”. If you would like to change the key go to your",
    "controls tab in options. The key you need to change is “Toggle Lua console”",
    "it’s located in the second column 2nd from bottom."
  }
  local admins = {
    "This list contains all the people that are admin in this world. Do you want to become",
    "an admin dont ask for it! an admin will see what you've made and the time you put",
    "in the server."
  }
  local players = {
    "These are the players who have supported us in the making of this factory. Without",
    "you the player we wouldn't have been as far as we are now"
  }
  if play.gui.center.README ~= nil then
    if page == "Rules" then
      if btn == true then
        play.gui.center.README.destroy()
        return
      end
      clearContent(play, rules)
      drawRules(play, play.gui.center.README, rules)
      return
    elseif page == "Server info" then
      clearContent(play)
      drawServerInfo(play, play.gui.center.README)
      return
    elseif page == "Chat" then
      clearContent(play, chat)
      drawChat(play, play.gui.center.README, chat)
      return                  
    elseif page == "Admins" then
      clearContent(play, admins)
      drawAdmins(play, play.gui.center.README, admins)
      return  
    elseif page == "Players" then
      clearContent(play, players)
      drawPlayers(play, play.gui.center.README, players)
      return
    else
      play.gui.center.README.destroy()
      return
    end
  else
    drawREADME(play, page)
    return
  end
end

function drawREADME(play, page)
  local frame = play.gui.center.add{name= "README", type = "frame", direction = "vertical"}
        frame.add{type = "scroll-pane", name= "flowContent", direction = "vertical", vertical_scroll_policy="always", horizontal_scroll_policy="never"}
        frame.add{type = "flow", name= "flowNavigation",direction = "horizontal"}
        frame.flowNavigation.add{name="btn_readme_rules", type = "button", caption="Rules", tooltip= "Rules."}
        frame.flowNavigation.add{name="btn_readme_server_info", type = "button", caption="Server info", tooltip= "Server information page."}
        frame.flowNavigation.add{name="btn_readme_chat", type = "button", caption="Chat", tooltip= "How to chat."}
        frame.flowNavigation.add{name="btn_readme_close", type = "button", caption="Close", tooltip= "Close the readme."}
        frame.flowContent.style.maximal_height = 400
        frame.flowContent.style.minimal_height = 400
        frame.flowContent.style.maximal_width = 500
        frame.flowContent.style.minimal_width = 500
        frame.flowNavigation.style.maximal_width = 500
        frame.flowNavigation.style.minimal_width = 500
  README_Controller(play, page)
end

function clearContent(play)
  if play.gui.center.flowcontent ~= nil then
    for i, element in pairs(play.gui.center.flowcontent.children_names) do
      play.gui.center.flowcontent[element].destroy()
    end
  end
end
function drawRules(play, frame, rules)
  frame.caption = "Rules"
  for i, rule in pairs(rules) do
    frame.flowContent.add{name=i, type="label", caption={"", i ,". ", rule}}
  end
end
function drawServerInfo(play, frame)
  frame.caption = "Server info"
  frame.flowContent.add{name="Discord", type="label", caption={"","Discord voice and chat server:"}}
  frame.flowContent.add{name="Discord_address", type="label", caption={"","https://discord.gg/RPCxzgt"}}
end
function drawChat(play, frame, chat)
  frame.caption = "Chat"
  for i, line in pairs(chat) do
    frame.flowContent.add{name=i, type="label", caption={"", line}}
  end
end
function drawAdmins(play, frame, admins)
  frame.caption = "Admins"
  for i, line in pairs(admins) do
    frame.flowContent.add{name=i, type="label", caption={"", line}}
  end
  drawPlayerTable(play, frame.flowContent, "AdminTable", true, nil, nil)
end
function drawPlayers(play, frame, players)
  frame.caption = "Players"
  for i, line in pairs(players) do
    frame.flowContent.add{name=i, type="label", caption={"", line}}
  end
  drawPlayerTable(play, frame.flowContent, "PlayerTable", false, nil, nil)
end